searchData={"items":[{"type":"module","title":"Gollum","doc":"Robots.txt parser with caching. Modelled after Kryten.\n\nUsage of `Gollum` would simply be to call `Gollum.crawlable?/3` to obtain\nwhether a certain URL is permitted for the specified user agent.\n\n`Gollum` is an OTP app (For the cache) so just remember to specify it in the\n`extra_applications` key in your `mix.exs` to ensure it is started.\n\n`Gollum` allows for some configuration in your `config.exs` file. The following\nshows their default values. They are all optional.\n```\nconfig :gollum,\n  name: Gollum.Cache, # Name of the Cache GenServer\n  refresh_secs: 86_400, # Amount of time before the robots.txt will be refetched\n  lazy_refresh: false, # Whether to setup a timer that auto-refetches, or to only refetch when requested\n  user_agent: \"Gollum\" # User agent to use when sending the GET request for the robots.txt\n```\n\nYou can also setup a `Gollum.Cache` manually using `Gollum.Cache.start_link/1`\nand add it to your supervision tree.","ref":"Gollum.html"},{"type":"function","title":"Gollum.crawlable?/3","doc":"Returns whether a url is permitted. `false` will be returned if an error occurs.","ref":"Gollum.html#crawlable?/3"},{"type":"function","title":"Options - Gollum.crawlable?/3","doc":"* `name` - The name of the GenServer. Default value is `Gollum.Cache`.\n\nAny other options passed will be passed to the internal `Cache.start_link/1` call.","ref":"Gollum.html#crawlable?/3-options"},{"type":"function","title":"Examples - Gollum.crawlable?/3","doc":"```\niex> Gollum.crawlable?(\"hello\", \"https://google.com/\")\n:crawlable\niex> Gollum.crawlable?(\"hello\", \"https://google.com/m/\")\n:uncrawlable\n```","ref":"Gollum.html#crawlable?/3-examples"},{"type":"module","title":"Gollum.Cache","doc":"Caches the robots.txt files from different hosts in memory.\n\nAdd this module to your supervision tree. Use this module to perform\nfetches of the robots.txt and automatic caching of results. It also\nmakes sure the two identical requests don't happen at the same time.","ref":"Gollum.Cache.html"},{"type":"function","title":"Gollum.Cache.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Gollum.Cache.html#child_spec/1"},{"type":"function","title":"Gollum.Cache.fetch/2","doc":"Fetches the robots.txt from a host and stores it in the cache.  \nIt will only perform the HTTP request if there isn't any current data in the cache, the\ndata is too old (specified in the `refresh_secs` option in `start_link/2`) or when the\n`force` flag is set. This function is useful if you know which hosts you need to request\nbeforehand.","ref":"Gollum.Cache.html#fetch/2"},{"type":"function","title":"Options - Gollum.Cache.fetch/2","doc":"* `name` - The name of the GenServer. Default value is `Gollum.Cache`.\n\n  * `async` - Whether this call is async. If the call is async, `:ok` is always\n    returned. The default value is `false`.\n\n  * `force` - If the cache has already fetched from the host, this flag determines\n    whether it should force a refresh. Default is `false`.","ref":"Gollum.Cache.html#fetch/2-options"},{"type":"function","title":"Gollum.Cache.get/2","doc":"Gets the `Gollum.Host` struct for the specified host from the cache.","ref":"Gollum.Cache.html#get/2"},{"type":"function","title":"Options - Gollum.Cache.get/2","doc":"* `name` - The name of the GenServer. Default value is `Gollum.Cache`.","ref":"Gollum.Cache.html#get/2-options"},{"type":"function","title":"Gollum.Cache.init/1","doc":"","ref":"Gollum.Cache.html#init/1"},{"type":"function","title":"Gollum.Cache.start_link/1","doc":"Starts up the cache.","ref":"Gollum.Cache.html#start_link/1"},{"type":"function","title":"Options - Gollum.Cache.start_link/1","doc":"* `name` - The name of the GenServer. Default value is `Gollum.Cache`.\n\n  * `refresh_secs` - The number of seconds until the robots.txt will be\n    refetched from the host. Defaults to `86_400`, which is 1 day.\n\n  * `lazy_refresh` - If this flag is set to `true`, the file will only be\n    refetched from the host if needed. Otherwise, the file will be\n    refreshed at the interval specified by `refresh_secs`. Defaults to\n    `false`.\n\n  * `user_agent` - The user agent to use when performing the GET request. Default\n    is `\"Gollum\"`.","ref":"Gollum.Cache.html#start_link/1-options"},{"type":"module","title":"Gollum.Fetcher","doc":"In charge of fetching the actual robots.txt files.","ref":"Gollum.Fetcher.html"},{"type":"function","title":"Gollum.Fetcher.fetch/2","doc":"Fetches the robots.txt file from the specified host. Simply performs\na `GET` request to the domain via `HTTPoison`.","ref":"Gollum.Fetcher.html#fetch/2"},{"type":"module","title":"Gollum.Host","doc":"Represents one host's robots.txt files.","ref":"Gollum.Host.html"},{"type":"function","title":"Gollum.Host.crawlable?/3","doc":"Returns whether a specified path is crawlable by the specified user agent,\nbased on the rules defined in the specified host struct.\n\nChecks are done based on the specification defined by Google, which can be\nfound [here](https://developers.google.com/search/reference/robots_txt).","ref":"Gollum.Host.html#crawlable?/3"},{"type":"function","title":"Examples - Gollum.Host.crawlable?/3","doc":"```\niex> alias Gollum.Host\niex> rules = %{\n...>   \"hello\" => %{\n...>     allowed: [\"/p\"],\n...>     disallowed: [\"/\"],\n...>   },\n...>   \"otherhello\" => %{\n...>     allowed: [\"/$\"],\n...>     disallowed: [\"/\"],\n...>   },\n...>   \"*\" => %{\n...>     allowed: [\"/page\"],\n...>     disallowed: [\"/*.htm\"],\n...>   },\n...> }\niex> host = Host.new(\"hello.net\", rules)\niex> Host.crawlable?(host, \"Hello\", \"/page\")\n:crawlable\niex> Host.crawlable?(host, \"OtherHello\", \"/page.htm\")\n:uncrawlable\niex> Host.crawlable?(host, \"NotHello\", \"/page.htm\")\n:uncrawlable\n```","ref":"Gollum.Host.html#crawlable?/3-examples"},{"type":"function","title":"Gollum.Host.new/2","doc":"Creates a new `Gollum.Host` struct, passing in the host and rules.\nThe rules usually are the output of the parser.","ref":"Gollum.Host.html#new/2"},{"type":"function","title":"Examples - Gollum.Host.new/2","doc":"```\niex> alias Gollum.Host\niex> rules = %{\"Hello\" => %{allowed: [], disallowed: []}}\niex> Host.new(\"hello.net\", rules)\n%Gollum.Host{host: \"hello.net\", rules: %{\"Hello\" => %{allowed: [], disallowed: []}}}\n```","ref":"Gollum.Host.html#new/2-examples"},{"type":"type","title":"Gollum.Host.t/0","doc":"","ref":"Gollum.Host.html#t:t/0"},{"type":"module","title":"Gollum.Parser","doc":"Parses a robots.txt file.","ref":"Gollum.Parser.html"},{"type":"function","title":"Gollum.Parser.parse/1","doc":"Parse the file, passed in as a simple binary.\n\nIt follows the [spec defined by Google](https://developers.google.com/search/reference/robots_txt)\nas closely as possible.","ref":"Gollum.Parser.html#parse/1"},{"type":"function","title":"Examples - Gollum.Parser.parse/1","doc":"```\niex> alias Gollum.Parser\niex> Parser.parse(\"User-agent: Hello\\nAllow: /hello\\nDisallow: /hey\")\n%{\"hello\" => %{allowed: [\"/hello\"], disallowed: [\"/hey\"]}}\n```","ref":"Gollum.Parser.html#parse/1-examples"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}